"use strict";
/*!
 * Copyright (c) 2019, 2022, 2023 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Eric Poirier <eric.poirier@eclipse-foundation.org>
 *   Olivier Goulet <olivier.goulet@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const parse_link_header_1 = __importDefault(require("parse-link-header"));
const utils_1 = require("../utils/utils");
require("isomorphic-fetch");
const apiBasePath = 'https://api.eclipse.org/adopters';
const getProjectsWithAdopters = (workingGroup, projects = [], nextUrl = undefined) => __awaiter(void 0, void 0, void 0, function* () {
    let url;
    if (!nextUrl) {
        url = `${apiBasePath}/projects`;
        url += workingGroup ? `?working_group=${workingGroup}` : '';
    }
    else {
        url = nextUrl;
    }
    if (!(0, utils_1.validateURL)(url))
        return projects;
    const response = yield fetch(url);
    const data = yield response.json();
    projects = projects.concat(data);
    const linkHeader = (0, parse_link_header_1.default)(response.headers.get('Link'));
    if (linkHeader === undefined || linkHeader.next === undefined)
        return projects;
    return getProjectsWithAdopters(workingGroup, projects, linkHeader.next.url);
});
exports.default = getProjectsWithAdopters;
