"use strict";
/*
 * Copyright (c) 2022, 2023 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Olivier Goulet <olivier.goulet@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.youtube = exports.playlistMapping = void 0;
require("isomorphic-fetch");
const apiBasePath = 'https://api.eclipse.org/media';
const playlistMapping = p => {
    return {
        id: p.id,
        title: p.snippet.title,
        description: p.snippet.description,
        publishedAt: p.snippet.published_at,
        thumbnails: p.snippet.thumbnails,
        channelId: p.snippet.channel_id,
        channelTitle: p.snippet.channel_title,
        player: {
            embedHtml: p.player.embed_html
        }
    };
};
exports.playlistMapping = playlistMapping;
const getPlaylistsFromChannel = (channelName) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        if (!channelName)
            throw Error(`No channel name was given to retrieve playlists`);
        const response = yield fetch(`${apiBasePath}/youtube/playlists?channel=${channelName}`);
        const data = yield response.json();
        const playlists = data.map(exports.playlistMapping);
        if (!response.ok)
            throw Error(`Could not fetch playlists for channel named ${channelName}`);
        return [playlists, null];
    }
    catch (error) {
        return [null, error];
    }
});
const getPlaylist = (playlistId) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        if (!playlistId)
            throw Error('No playlist id was given');
        const response = yield fetch(`${apiBasePath}/youtube/playlists/${playlistId}`);
        const data = yield response.json();
        const playlist = (0, exports.playlistMapping)(data);
        if (!response.ok)
            throw Error(`Could not fetch playlist using playlist id ${playlistId}`);
        return [playlist, null];
    }
    catch (error) {
        return [null, error];
    }
});
const getPlaylists = (playlistIds = []) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        if (playlistIds.length === 0)
            throw Error('No playlist ids were provided');
        const responses = yield playlistIds
            .reduce((accumulator, id) => __awaiter(void 0, void 0, void 0, function* () {
            const [playlist, error] = yield getPlaylist(id);
            // Add playlist to playlists array in accumulator
            (yield accumulator)[0].push(playlist);
            // Add error to errors array in accumulator
            (yield accumulator)[1].push(error);
            return accumulator;
        }), [[], []]);
        return responses;
    }
    catch (error) {
        return [null, error];
    }
});
exports.youtube = {
    getPlaylistsFromChannel,
    getPlaylist,
    getPlaylists
};
