"use strict";
/*!
 * Copyright (c) 2021 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Christopher Guindon <chris.guindon@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const parse_link_header_1 = __importDefault(require("parse-link-header"));
require("isomorphic-fetch");
const getMembers = (url = '', members = [], errHandler) => {
    return new Promise((resolve, reject) => fetch(url)
        .then((response) => {
        if (response.status !== 200) {
            throw `${response.status}: ${response.statusText}`;
        }
        response
            .json()
            .then((data) => {
            members = members.concat(data);
            const linkHeader = (0, parse_link_header_1.default)(response.headers.get('Link'));
            if (linkHeader === null || linkHeader === void 0 ? void 0 : linkHeader.next) {
                const { url } = linkHeader.next;
                getMembers(url, members, errHandler).then(resolve).catch(reject);
            }
            else {
                members.sort((a, b) => a.name.localeCompare(b.name));
                resolve(members);
            }
        })
            .catch(reject);
    })
        .catch((err) => {
        errHandler && errHandler(err);
        reject(err);
    }));
};
exports.default = getMembers;
