"use strict";
/*
 * Copyright (c) 2023 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Olivier Goulet <olivier.goulet@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getProjectParticipatingOrganizations = exports.getOrganizations = exports.getOrganizationById = exports.organizationMapper = void 0;
require("isomorphic-fetch");
const utils_1 = require("../utils/utils");
const apiBasePath = 'https://membership.eclipse.org/api';
const organizationMapper = organization => {
    const { organization_id: organizationId } = organization, otherOrganizationFields = __rest(organization, ["organization_id"]);
    return Object.assign({ organizationId }, otherOrganizationFields);
};
exports.organizationMapper = organizationMapper;
const getOrganizationById = (organizationId) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const response = yield fetch(`${apiBasePath}/organizations/${organizationId}`);
        if (!response.ok)
            throw new Error(`Could not fetch organization by id ${organizationId}`);
        const data = yield response.json();
        const organization = (0, exports.organizationMapper)(data);
        return [organization, null];
    }
    catch (error) {
        console.error(error);
        return [null, error];
    }
});
exports.getOrganizationById = getOrganizationById;
const getOrganizations = (params = {}) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const queryString = (0, utils_1.convertToQueryString)(params);
        const response = yield fetch(`${apiBasePath}/organizations?${queryString}`);
        if (!response.ok) {
            throw new Error(`Could not fetch organizations`);
        }
        const data = yield response.json();
        const organizations = data
            .map(exports.organizationMapper);
        return [organizations, null];
    }
    catch (error) {
        console.error(error);
        return [null, 'An unexpected error has occurred when fetching organizations'];
    }
});
exports.getOrganizations = getOrganizations;
const getProjectParticipatingOrganizations = (projectId, params = {}) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        if (!projectId) {
            throw new Error('No project id provided for fetching project participating organizations');
        }
        const queryString = (0, utils_1.convertToQueryString)(params);
        const response = yield fetch(`${apiBasePath}/projects/${projectId}/organizations?${queryString}`);
        if (!response.ok) {
            throw new Error(`Could not fetch project organizations for project id "${projectId}"`);
        }
        const data = yield response.json();
        const organizations = data
            .map(exports.organizationMapper)
            .sort((a, b) => a.name.localeCompare(b.name));
        return [organizations, null];
    }
    catch (error) {
        console.error(error);
        return [
            null,
            'An unexpected error has occurred when fetching participating organizations for project',
        ];
    }
});
exports.getProjectParticipatingOrganizations = getProjectParticipatingOrganizations;
