"use strict";
/*!
 * Copyright (c) 2021, 2023 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Eric Poirier <eric.poirier@eclipse-foundation.org>
 *   Olivier Goulet <olivier.goulet@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getProjectProposals = exports.getProjectsData = void 0;
const parse_link_header_1 = __importDefault(require("parse-link-header"));
const utils_1 = require("../utils/utils");
require("isomorphic-fetch");
const eclipseProjectsUrl = "https://projects.eclipse.org/projects/";
const throwFetchError = ({ status, statusText } = response) => {
    throw `${status}: ${statusText}`;
};
const getProjectsDataFromAPI = (url, projects = []) => {
    if ((0, utils_1.validateURL)(url)) {
        return new Promise((resolve, reject) => fetch(url)
            .then((response) => {
            if (response.status !== 200)
                throwFetchError(response);
            response
                .json()
                .then((data) => {
                var _a;
                projects = projects.concat(data);
                const linkHeader = (0, parse_link_header_1.default)(response.headers.get('Link'));
                if ((linkHeader === null || linkHeader === void 0 ? void 0 : linkHeader.next) && typeof ((_a = linkHeader.next) === null || _a === void 0 ? void 0 : _a.url) === 'string') {
                    getProjectsDataFromAPI(linkHeader.next.url, projects).then(resolve).catch(reject);
                }
                else {
                    projects.forEach((project, key) => {
                        projects[key].version = 'none';
                        if (project.releases[0]) {
                            projects[key].version = project.releases[0].name;
                        }
                        if (typeof projects[key].website_url === "undefined" || projects[key].website_url === "") {
                            projects[key].website_url = eclipseProjectsUrl + projects[key].project_id;
                        }
                    });
                    projects.sort((a, b) => a.name.localeCompare(b.name));
                    resolve(projects);
                }
            })
                .catch(reject);
        })
            .catch((err) => {
            reject(err);
        }));
    }
};
const getProjectsDataFromStaticSource = (url) => {
    if (!(0, utils_1.validateURL)(url))
        return;
    return new Promise((resolve, reject) => fetch(url)
        .then(response => {
        if (response.status !== 200)
            throw `${response.status}: ${response.statusText}`;
        response
            .json()
            .then((projects) => {
            projects.forEach((_, key) => {
                if (typeof projects[key].website_url === "undefined" || projects[key].website_url === "") {
                    projects[key].website_url = eclipseProjectsUrl + projects[key].project_id;
                }
            });
            projects.sort((a, b) => a.name.localeCompare(b.name));
            resolve(projects);
        })
            .catch(reject);
    })
        .catch((err) => reject(err)));
};
const getProjectsData = (url, isStaticSource) => {
    let projects;
    if (isStaticSource) {
        projects = getProjectsDataFromStaticSource(url);
    }
    else {
        projects = getProjectsDataFromAPI(url);
    }
    return projects;
};
exports.getProjectsData = getProjectsData;
const apiBasePath = 'https://projects.eclipse.org/api';
const getProjectProposals = (industryCollaborationId) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        let proposals = [];
        let nextPage = `${apiBasePath}/proposals`;
        if (industryCollaborationId) {
            nextPage += `?industry_collaboration=${industryCollaborationId}`;
        }
        while (nextPage) {
            const response = yield fetch(nextPage);
            if (!response.ok)
                throw new Error('Could not retrieve project proposals');
            const data = yield response.json();
            if (data === null || data === void 0 ? void 0 : data.result) {
                proposals = proposals.concat(data.result);
            }
            const linkHeader = response.headers.get('Link');
            nextPage = (0, utils_1.getNextPage)(linkHeader);
        }
        return [proposals, null];
    }
    catch (error) {
        console.error(error);
        return [null, error];
    }
});
exports.getProjectProposals = getProjectProposals;
