"use strict";
/*
 * Copyright (c) 2022, 2023 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Olivier Goulet <olivier.goulet@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const eclipsefdn_adopters_1 = __importDefault(require("../eclipsefdn.adopters"));
const mock_data_1 = require("./mocks/adopters/mock-data");
describe('Adopters API', () => {
    it('Fetches projects with adopters', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield (0, eclipsefdn_adopters_1.default)('internet-things-iot');
        expect(result).not.toBeNull();
        expect(result).not.toHaveLength(0);
        expect(result[0]).toHaveProperty('adopters');
    }));
    it('Fetches correct number of projects with adopters', () => __awaiter(void 0, void 0, void 0, function* () {
        // Tests whether the link header fetching works
        const result = yield (0, eclipsefdn_adopters_1.default)('internet-things-iot');
        const numberOfProjectsWithAdopters = mock_data_1.mockAdoptersCategorizedByWorkingGroup['internet-things-iot'].length;
        expect(result).toHaveLength(numberOfProjectsWithAdopters);
    }));
});
