"use strict";
/*
 * Copyright (c) 2023 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Olivier Goulet <olivier.goulet@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const eclipsefdn_newsroom_1 = require("../eclipsefdn.newsroom");
describe('Newsroom API', () => {
    it('Should return a list of resources', () => __awaiter(void 0, void 0, void 0, function* () {
        const [newsroomResources, error] = yield (0, eclipsefdn_newsroom_1.getNewsroomResources)();
        expect(error).toBeNull();
        expect(newsroomResources).not.toBeNull();
    }));
    it('Should return a list of a specified resource type from the `resourceTypes` parameter', () => __awaiter(void 0, void 0, void 0, function* () {
        const [caseStudies] = yield (0, eclipsefdn_newsroom_1.getNewsroomResources)({
            resourceTypes: ['case_study']
        });
        const [whitePapers] = yield (0, eclipsefdn_newsroom_1.getNewsroomResources)({
            resourceTypes: ['white_paper']
        });
        expect(caseStudies.length).toBeGreaterThan(0);
        expect(whitePapers.length).toBeGreaterThan(0);
        expect(caseStudies.every(r => r.resource_type.includes('case_study'))).toBe(true);
        expect(whitePapers.every(r => r.resource_type.includes('white_paper'))).toBe(true);
    }));
    it('Should return a list of resources of a specified publishing location from the `publishTo` parameter', () => __awaiter(void 0, void 0, void 0, function* () {
        const [newsroomResources] = yield (0, eclipsefdn_newsroom_1.getNewsroomResources)({
            publishTo: ['eclipse_org']
        });
        expect(newsroomResources.length).toBeGreaterThan(0);
        expect(newsroomResources.every(r => r.publish_to.includes('eclipse_org'))).toBe(true);
    }));
    it('Allow for multiple `publishTo` parameters', () => __awaiter(void 0, void 0, void 0, function* () {
        const [newsroomResources] = yield (0, eclipsefdn_newsroom_1.getNewsroomResources)({
            publishTo: ['eclipse_org', 'sparkplug']
        });
        expect(newsroomResources.every(r => r.publish_to.includes('eclipse_org') || r.publish_to.includes('sparkplug'))).toBe(true);
        expect(newsroomResources.find(r => r.publish_to.includes('eclipse_org'))).not.toBeNull();
        expect(newsroomResources.find(r => r.publish_to.includes('sparkplug'))).not.toBeNull();
    }));
    it('Limit the number of resources with the `pageSize` parameter', () => __awaiter(void 0, void 0, void 0, function* () {
        const [newsroomResources] = yield (0, eclipsefdn_newsroom_1.getNewsroomResources)({
            pageSize: 3
        });
        expect(newsroomResources).toHaveLength(3);
    }));
});
