"use strict";
/*
 * Copyright (c) 2023 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Olivier Goulet <olivier.goulet@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const eclipsefdn_projects_1 = require("../eclipsefdn.projects");
const mock_data_1 = require("./mocks/projects/mock-data");
describe('Projects API', () => {
    it('Fetches all proposals', () => __awaiter(void 0, void 0, void 0, function* () {
        const [result, error] = yield (0, eclipsefdn_projects_1.getProjectProposals)();
        expect(result).not.toBeNull();
        expect(error).toBeNull();
        expect(result).toHaveLength(mock_data_1.mockProposals.length);
        expect(result[0]).toHaveProperty('project_id');
    }));
    it('Fetches proposals for a specific industry collaboration', () => __awaiter(void 0, void 0, void 0, function* () {
        const [result, error] = yield (0, eclipsefdn_projects_1.getProjectProposals)('jakarta-ee');
        expect(result).not.toBeNull();
        expect(error).toBeNull();
        expect(result).toHaveLength(mock_data_1.mockProposalsCategorizedByIndustryCollaboration['jakarta-ee'].length);
        expect(result[0]).toHaveProperty('project_id');
    }));
    it('Resolves empty array when no proposals found', () => __awaiter(void 0, void 0, void 0, function* () {
        const [result] = yield (0, eclipsefdn_projects_1.getProjectProposals)('eclipse-software-defined-vehicle');
        expect(result).toEqual([]);
    }));
});
