"use strict";
/*
 * Copyright (c) 2023 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Olivier Goulet <olivier.goulet@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
const msw_1 = require("msw");
const mock_data_1 = require("./mock-data");
const mock_helpers_1 = require("../mock-helpers");
const apiUrl = 'https://projects.eclipse.org/api';
const handlers = [
    msw_1.rest.get(`${apiUrl}/proposals`, (req, res, ctx) => {
        const industryCollaboration = req.url.searchParams.get('industry_collaboration');
        const page = +req.url.searchParams.get('page') || 1;
        const pageSize = 3;
        const proposals = industryCollaboration
            ? mock_data_1.mockProposalsCategorizedByIndustryCollaboration[industryCollaboration]
            : mock_data_1.mockProposals;
        // Pagination mock
        const hasMoreProposals = page * pageSize < proposals.length;
        const linkHeader = (0, mock_helpers_1.buildMockPaginationLinkHeader)(req, hasMoreProposals);
        const startIndex = (page - 1) * pageSize;
        const remainingDataCount = proposals.length - startIndex;
        const endIndex = startIndex + Math.min(pageSize, remainingDataCount);
        const result = proposals.length === 0 ? [] : {
            result: proposals.slice(startIndex, endIndex)
        };
        return res(ctx.status(200), ctx.set({
            Link: linkHeader,
        }), ctx.json(result));
    }),
];
exports.default = handlers;
