"use strict";
/*!
 * Copyright (c) 2021 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Eric Poirier <eric.poirier@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mustache_1 = __importDefault(require("mustache"));
const loading_icon_mustache_1 = __importDefault(require("./templates/loading-icon.mustache"));
require("jquery-match-height");
const tpl_news_tag_item_mustache_1 = __importDefault(require("./templates/tpl-news-tag-item.mustache"));
require("numeral");
const eclipsefdn_news_1 = __importDefault(require("../api/eclipsefdn.news"));
const EclipseFdnNewsTags = (() => __awaiter(void 0, void 0, void 0, function* () {
    const element = document.querySelector('.news-tags-sidebar');
    if (!element) {
        return;
    }
    element.innerHTML = (0, loading_icon_mustache_1.default)();
    const options = Object.assign({}, element.dataset);
    let newsData = yield (0, eclipsefdn_news_1.default)(options.url, []);
    let tagTitles = [];
    let dataTags = [];
    Promise.allSettled([newsData])
        .then(function (responses) {
        if (responses[0].status === 'fulfilled') {
            const news = responses[0].value;
            if (news.length > 0) {
                // Go through each news items
                news.forEach((newsItem) => {
                    tagTitles = tagTitles.concat(newsItem.tags);
                });
                // Counting each tags
                let counts = {};
                for (const title of tagTitles) {
                    counts[title] = counts[title] ? counts[title] + 1 : 1;
                }
                // Build dataTags array for mustache
                let uniqueTags = [...new Set(tagTitles)];
                uniqueTags.forEach((tag) => {
                    let array = {};
                    array.title = tag;
                    array.count = counts[tag];
                    const urlSegments = window.location.href.split('?');
                    const currentPath = urlSegments[0].replace(/\/+$/, '');
                    array.url = currentPath + '?news_tags=' + tag;
                    dataTags = dataTags.concat(array);
                });
            }
        }
        const data = {
            items: dataTags,
        };
        // Render component
        element.innerHTML = (0, tpl_news_tag_item_mustache_1.default)(data);
    })
        .catch(err => console.log(err));
}))();
exports.default = EclipseFdnNewsTags;
