"use strict";
/*!
 * Copyright (c) 2022, 2023 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Zhou Fang <zhou.fang@eclipse-foundation.org>
 *   Olivier Goulet <olivier.goulet@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const resources_list_mustache_1 = __importDefault(require("./templates/newsroom-resources/resources-list.mustache"));
const resources_image_mustache_1 = __importDefault(require("./templates/newsroom-resources/resources-image.mustache"));
const resources_image_with_title_mustache_1 = __importDefault(require("./templates/newsroom-resources/resources-image-with-title.mustache"));
const resources_cover_mustache_1 = __importDefault(require("./templates/newsroom-resources/resources-cover.mustache"));
const eclipsefdn_newsroom_1 = require("../api/eclipsefdn.newsroom");
const render_template_1 = __importDefault(require("./templates/render-template"));
const templates = {
    list: resources_list_mustache_1.default,
    image: resources_image_mustache_1.default,
    'image-with-title': resources_image_with_title_mustache_1.default,
    cover: resources_cover_mustache_1.default,
};
// Converts a string date to a more readable format.
const formatDate = (dateStr) => {
    let date = new Date(dateStr).toDateString();
    date = date.slice(0, 3) + ',' + date.slice(3);
    return date;
};
// Get the link and icon for the resource item.
const linkReducer = (linkType, newsroomResource) => {
    switch (linkType) {
        case 'direct':
            return newsroomResource.direct_link
                ? ({ link: newsroomResource.direct_link || '', icon: 'pdf', type: 'PDF' })
                : ({ link: newsroomResource.landing_link || '', icon: 'text', type: 'HTML' });
        default:
            return newsroomResource.landing_link
                ? ({ link: newsroomResource.landing_link || '', icon: 'text', type: 'HTML' })
                : ({ link: newsroomResource.direct_link || '', icon: 'pdf', type: 'PDF' });
    }
};
const render = () => __awaiter(void 0, void 0, void 0, function* () {
    const resourcesElements = Array.from(document.querySelectorAll('.newsroom-resources'));
    if (resourcesElements.length === 0)
        return;
    yield Promise.all(resourcesElements.map((resourcesElement) => __awaiter(void 0, void 0, void 0, function* () {
        var _a, _b, _c, _d;
        const pageSizeDataAttribute = resourcesElement.dataset.pageSize || resourcesElement.dataset.resLimit;
        const options = {
            resourceTypes: (_a = resourcesElement.dataset.resType) === null || _a === void 0 ? void 0 : _a.replaceAll(', ', ',').split(','),
            publishTo: (_b = resourcesElement.dataset.resWg) === null || _b === void 0 ? void 0 : _b.replaceAll(', ', ',').split(','),
            viewMoreLinks: (_c = resourcesElement.dataset.resViewMore) === null || _c === void 0 ? void 0 : _c.replaceAll(', ', ',').split(','),
            titles: (_d = resourcesElement.dataset.resTitle) === null || _d === void 0 ? void 0 : _d.replaceAll(', ', ',').split(','),
            linkType: resourcesElement.dataset.resLink,
            templateId: resourcesElement.dataset.resTemplate,
            pageSize: pageSizeDataAttribute ? parseInt(pageSizeDataAttribute) : null
        };
        // If the template displays types as separate sections, we would need to alter the way we fetch data.
        const hasSections = options.templateId === 'list';
        let newsroomResources;
        let newsroomResourcesGroupedBySection = {};
        let error;
        if (hasSections) {
            const results = yield Promise.all(options.resourceTypes.map((resourceType) => __awaiter(void 0, void 0, void 0, function* () {
                let [newsroomResourcesOfSection] = yield (0, eclipsefdn_newsroom_1.getNewsroomResources)({
                    resourceTypes: [resourceType],
                    publishTo: options.publishTo,
                    pageSize: options.pageSize,
                });
                return { resourceType, newsroomResources: newsroomResourcesOfSection };
            })));
            results.forEach(r => newsroomResourcesGroupedBySection[r.resourceType] = r.newsroomResources);
        }
        else {
            [newsroomResources, error] = yield (0, eclipsefdn_newsroom_1.getNewsroomResources)({
                resourceTypes: options.resourceTypes,
                publishTo: options.publishTo,
                pageSize: options.pageSize,
            });
        }
        let data;
        if (hasSections) {
            data = {
                items: options.resourceTypes.map((resourceType, i) => ({
                    isFetching: false,
                    title: options.titles[i],
                    data: newsroomResourcesGroupedBySection[resourceType]
                        .map(r => ({
                        resClass: resourcesElement.getAttribute('data-res-class'),
                        title: r.title,
                        image: r.image,
                        resLink: linkReducer(options.linkType, r),
                    })),
                }))
            };
        }
        else {
            data = {
                items: {
                    isFetching: false,
                    title: options.titles[0],
                    viewMoreLink: options.viewMoreLinks ? options.viewMoreLinks[0] : null,
                    data: newsroomResources.map(r => ({
                        resClass: resourcesElement.getAttribute('data-res-class'),
                        title: r.title,
                        image: r.image,
                        date: formatDate(r.date),
                        resLink: linkReducer(options.linkType, r),
                    })),
                }
            };
        }
        yield (0, render_template_1.default)(resourcesElement, templates, options.templateId, data);
    })));
});
exports.default = { render };
