"use strict";
/*!
 * Copyright (c) 2021, 2023 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Olivier Goulet <olivier.goulet@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const loading_icon_mustache_1 = __importDefault(require("./templates/loading-icon.mustache"));
const logo_list_mustache_1 = __importDefault(require("./templates/logo-list.mustache"));
const eclipsefdn_membership_1 = require("../api/eclipsefdn.membership");
const render_template_1 = __importDefault(require("./templates/render-template"));
const defaultOptions = {
    templateId: 'default',
    projectShortId: undefined
};
const templates = {
    default: logo_list_mustache_1.default
};
const render = () => __awaiter(void 0, void 0, void 0, function* () {
    const element = document.querySelector('.eclipsefdn-participating-organizations');
    if (!element)
        return;
    element.innerHTML = (0, loading_icon_mustache_1.default)();
    const options = Object.assign(Object.assign({}, defaultOptions), element.dataset);
    if (!options.projectShortId)
        return;
    let [participatingOrganizations] = yield (0, eclipsefdn_membership_1.getProjectParticipatingOrganizations)(options.projectShortId);
    if (!participatingOrganizations)
        return;
    const data = {
        items: participatingOrganizations.map(organization => ({
            id: organization.organizationId,
            name: organization.name,
            logo: organization.logos.web
        }))
    };
    yield (0, render_template_1.default)(element, templates, options.templateId, data);
});
const eclipsefdnParticipatingOrganizations = {
    render
};
exports.default = eclipsefdnParticipatingOrganizations;
