"use strict";
/*!
 * Copyright (c) 2021, 2023 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Eric Poirier <eric.poirier@eclipse-foundation.org>
 *   Olivier Goulet <olivier.goulet@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jquery_1 = __importDefault(require("jquery"));
const mustache_1 = __importDefault(require("mustache"));
require("jquery-match-height");
const tpl_projects_item_mustache_1 = __importDefault(require("./templates/tpl-projects-item.mustache"));
require("numeral");
const list_js_1 = __importDefault(require("list.js"));
const eclipsefdn_projects_1 = require("../api/eclipsefdn.projects");
const projectsAlphanumericComparator = (projectA, projectB) => {
    if (projectA.name < projectB.name)
        return -1;
    if (projectA.name > projectB.name)
        return 1;
    return 0;
};
// Shuffles an array randomly using the Array.sort() method
const shuffle = () => {
    return 0.5 - Math.random();
};
// Maps a project or project proposal into data accepted by the template
const projectMapper = (data) => {
    return {
        name: data.name,
        summary: data.summary,
        logo: data.isProposal ? '' : data.logo,
        category: data.isProposal ? 'Project Proposal' : data.category,
        website_url: data.isProposal ? data.project_url : data.website_url,
        version: data.version,
        state: data.state,
        isProposal: data.isProposal || false
    };
};
const extractWorkingGroupIdFromUrl = (url) => {
    if (!url)
        return;
    return new URL(url).searchParams.get('working_group');
};
const validTypes = new Set(['projects', 'proposals']);
const defaultOptions = {
    id: '',
    templateId: '',
    projectIds: '',
    url: '',
    isStaticSource: false,
    types: ['projects', 'proposals'],
    pageSize: null,
    sortingMethod: 'alphanumeric' // 'alphanumeric' or 'random'
};
const render = () => __awaiter(void 0, void 0, void 0, function* () {
    const element = document.querySelector('.featured-projects');
    if (!element)
        return;
    const options = Object.assign(Object.assign(Object.assign({}, defaultOptions), element.dataset), { isStaticSource: element.dataset.isStaticSource === 'true', types: element.dataset.types
            ? element.dataset.types.split(',').map(t => t.trim())
            : defaultOptions.types });
    options.types.forEach(t => {
        if (!validTypes.has(t)) {
            console.error(`Invalid type provided to featured-projects "${t}"`);
        }
    });
    function fetchCategories() {
        let elem = document.getElementById('projects-categories');
        if (elem !== null) {
            let categoriesUrl = elem.getAttribute('data-categories');
            return fetch(categoriesUrl).then(response => response.json());
        }
        // returning an empty promise if categories were not passed.
        return () => __awaiter(this, void 0, void 0, function* () { });
    }
    let resultsProjects = [];
    let resultsCategories = [];
    let resultsProjectProposals = [];
    // Fetch projects
    let projectsData = [];
    if (options.types.includes('projects')) {
        projectsData = yield (0, eclipsefdn_projects_1.getProjectsData)(options.url, options.isStaticSource);
    }
    // Fetch project proposals. We don't want to include static source projects here.
    if (options.types.includes('proposals') && !options.isStaticSource) {
        const workingGroupId = extractWorkingGroupIdFromUrl(options.url);
        const [proposals] = yield (0, eclipsefdn_projects_1.getProjectProposals)(workingGroupId);
        if (proposals)
            resultsProjectProposals = proposals;
    }
    ;
    Promise.allSettled([projectsData, fetchCategories()])
        .then(function (responses) {
        if (responses[0].status === 'fulfilled') {
            const projects = responses[0].value;
            if (projects.length > 0) {
                resultsProjects = projects;
            }
        }
        if (responses[1].status === 'fulfilled') {
            resultsCategories = responses[1].value;
        }
        (0, jquery_1.default)(resultsProjects).each(function (key, project) {
            // Populate the Tags array
            if (resultsCategories.length <= 0 && typeof resultsProjects[key].tags !== "undefined") {
                const project_tags = resultsProjects[key].tags;
                if (project_tags.length !== 0) {
                    tags[resultsProjects[key].project_id] = project_tags;
                }
            }
        });
        let projects = [
            ...resultsProjects,
            ...resultsProjectProposals.map(p => (Object.assign(Object.assign({}, p), { isProposal: true, category: 'Project Proposal' })))
        ];
        projects = projects
            .sort(options.sortingMethod === 'random' ? shuffle : projectsAlphanumericComparator)
            .slice(0, options.pageSize || projects.length)
            .map(p => (Object.assign(Object.assign({}, p), { category: getCategory(resultsCategories, p.project_id).toString() })))
            .map(projectMapper);
        const data = {
            items: projects
        };
        // Render component
        let html = '';
        if (options.templateId !== '' && document.getElementById(options.templateId)) {
            const theme = document.getElementById(options.templateId).innerHTML;
            html = mustache_1.default.render(theme, data);
        }
        else {
            html = (0, tpl_projects_item_mustache_1.default)(data);
        }
        element.innerHTML += html;
        if (resultsCategories.length <= 0) {
            resultsCategories = tags;
        }
        const hasFilters = document.querySelector('.eclipsefdn-project-list-filters');
        if (hasFilters && options.pageSize) {
            console.warn('Using pagination with filters is not supported.');
        }
        else {
            jquery_1.default.each(resultsCategories, function (key, projects) {
                jquery_1.default.each(projects, function (key, value) {
                    let duplicate = (0, jquery_1.default)('.eclipsefdn-project-list-filters').find("button:contains('" + value + "')");
                    if (duplicate.length > 0) {
                        return;
                    }
                    let button = document.createElement('button');
                    button.innerHTML = value;
                    button.className = 'btn btn-filter-project';
                    button.setAttribute('data-toggle', 'button');
                    (0, jquery_1.default)('.eclipsefdn-project-list-filters').append(button);
                });
            });
        }
        const values = {
            valueNames: [
                'name',
                'category'
            ],
        };
        let list = new list_js_1.default('projects-list', values);
        // Recalculate heights after search or filter
        const recalculateHeights = () => {
            (0, jquery_1.default)('.featured-projects-item').matchHeight({ byRow: true });
        };
        list.on('filterComplete', recalculateHeights);
        list.on('searchComplete', recalculateHeights);
        (0, jquery_1.default)('.btn-filter-project').on('click', function (elem) {
            (0, jquery_1.default)('.btn-filter-project').not(this).each(function () {
                (0, jquery_1.default)(this).removeClass('active');
            });
            setTimeout(function () {
                list.filter(computeFilterFunction);
            }, 10);
        });
        jquery_1.default.fn.matchHeight._applyDataApi();
    })
        .catch(err => console.log(err));
    let tags = {};
    let getCategory = function (categories, project_id) {
        let category = "Other Tools";
        if (typeof categories[project_id] !== "undefined") {
            category = categories[project_id];
        }
        if (categories.length <= 0 && typeof tags[project_id] !== "undefined") {
            category = tags[project_id].toString().split(',').join(', ');
        }
        return category;
    };
    let computeFilterFunction = function (item) {
        let filter = [];
        (0, jquery_1.default)('.btn-filter-project').each(function (index, elem) {
            if ((0, jquery_1.default)(elem).hasClass('active')) {
                filter.push((0, jquery_1.default)(elem).text());
            }
        });
        if (filter.length == 0) {
            return true;
        }
        let found = false;
        for (let i = 0; i < filter.length; i++) {
            const element = filter[i];
            if (typeof item.values().category !== "undefined" && item.values().category.indexOf(element) !== -1) {
                found = true;
                continue;
            }
            found = false;
            break;
        }
        return found;
    };
});
const eclipsefdnProjects = {
    render
};
exports.default = eclipsefdnProjects;
