"use strict";
/*
 * Copyright (c) 2022, 2023 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Olivier Goulet <olivier.goulet@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const video_list_mustache_1 = __importDefault(require("./templates/video-list.mustache"));
const loading_icon_mustache_1 = __importDefault(require("./templates/loading-icon.mustache"));
const render_template_1 = __importDefault(require("./templates/render-template"));
const eclipsefdn_media_link_1 = require("../api/eclipsefdn.media-link");
const eclipsefdn_videos_1 = require("../privacy/eclipsefdn.videos");
const defaultOptions = {
    templateId: 'default',
    channel: 'eclipsefdn',
    playlistIds: '',
    tags: [],
    descriptionMaxLength: 200
};
const templates = {
    default: video_list_mustache_1.default
};
const render = () => __awaiter(void 0, void 0, void 0, function* () {
    const element = document.querySelector('.eclipsefdn-video-list');
    if (!element)
        return;
    element.innerHTML = (0, loading_icon_mustache_1.default)();
    const options = Object.assign(Object.assign({}, defaultOptions), element.dataset);
    if (options.playlistIds === '') {
        console.error('No playlist id(s) provided');
        return;
    }
    ;
    const playlistIds = options.playlistIds
        .split(',')
        .map(id => id.trim());
    const [playlists] = yield eclipsefdn_media_link_1.youtube.getPlaylists(playlistIds);
    // Get playlists from given ids and apply max length to descriptions
    const playlistsData = playlists
        .map(p => (Object.assign(Object.assign({}, p), { description: p.description.length <= 0
            ? ''
            : p.description
                .slice(0, options.descriptionMaxLength - 3)
                .concat('...') })));
    yield (0, render_template_1.default)(element, templates, options.templateId, { items: playlistsData });
    // Video embeds need to be re-rendered since this is asynchronous
    (0, eclipsefdn_videos_1.renderVideos)();
});
const eclipsefdnVideoList = {
    render
};
exports.default = eclipsefdnVideoList;
