"use strict";
/**
 * @jest-environment jsdom
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2023 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Olivier Goulet <olivier.goulet@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */
const eclipsefdn_members_list_1 = __importDefault(require("../eclipsefdn.members-list"));
const interestGroupAPI = __importStar(require("../../api/eclipsefdn.interest-groups"));
const mock_data_1 = require("../../api/tests/mocks/interest-groups/mock-data");
describe('eclipsefdn-members-list', () => {
    let getInterestGroupParticipatingOrganizationsSpy;
    beforeEach(() => {
        getInterestGroupParticipatingOrganizationsSpy = jest.spyOn(interestGroupAPI, 'getInterestGroupParticipatingOrganizations');
    });
    // TODO: Remove skip once mustache-loader has been replaced with handlebars-loader.
    it.skip('Renders interest group members', () => __awaiter(void 0, void 0, void 0, function* () {
        const shortId = 'openmobility';
        const participatingOrganizations = mock_data_1.mockParticipatingOrganizationsCategorizedByInterestGroup[shortId];
        getInterestGroupParticipatingOrganizationsSpy.mockReturnValue([
            participatingOrganizations,
            null,
        ]);
        document.querySelector('body').innerHTML = `
        <ul
            class="eclipsefdn-members-list"
            data-type="interest-group"
            data-id="${shortId}"
            data-ml-template="only-logos"
        >
        </ul>
    `;
        eclipsefdn_members_list_1.default.render();
        // This hack is needed to ensure the members-list has rendered but it is not guaranteed to work.
        // This should be replaced with `await render()` once eclipsefdn-members-list uses
        // `renderTemplate`.
        yield new Promise(resolve => setTimeout(() => resolve(), 1000));
        expect(getInterestGroupParticipatingOrganizationsSpy).toHaveBeenCalledWith({
            interestGroupId: shortId,
        });
        const logoElements = Array.from(document.querySelectorAll('.eclipsefdn-members-list img'));
        // Fetching member names through alt text as they match one-to-one.
        const namesOfDisplayedMembers = logoElements
            .map(logoElement => logoElement.getAttribute('alt'))
            .sort();
        const participatingOrganizationNames = participatingOrganizations
            .map(organization => organization.name)
            .filter((value, i, arr) => arr.indexOf(value) === i)
            .sort();
        expect(namesOfDisplayedMembers).toEqual(participatingOrganizationNames);
    }));
    it.skip('Shows member as text when no logo is present', () => __awaiter(void 0, void 0, void 0, function* () {
        const shortId = 'openmobility';
        // Mutating the first element of participating organizations to ensure the web logo is `null`.
        // Everything else is set to a url mock.
        let participatingOrganizations = mock_data_1.mockParticipatingOrganizationsCategorizedByInterestGroup[shortId];
        participatingOrganizations.forEach((_, i) => participatingOrganizations[i].logos.web = 'some url');
        participatingOrganizations[0].logos.web = null;
        getInterestGroupParticipatingOrganizationsSpy.mockReturnValue([
            participatingOrganizations,
            null
        ]);
        document.querySelector('body').innerHTML = `
      <ul
        class="eclipsefdn-members-list"
        data-type="interest-group"
        data-id="${shortId}"
        data-ml-template="only-logos"
      >
      </ul>
    `;
        eclipsefdn_members_list_1.default.render();
        // This hack is needed to ensure the members-list has rendered but it is not guaranteed to work.
        // This should be replaced with `await render()` once eclipsefdn-members-list uses
        // `renderTemplate`.
        yield new Promise(resolve => setTimeout(() => resolve(), 1000));
        // We expect one of the elements to not have a logo. So we subtract one.
        const expectedLogoCount = participatingOrganizations.length - 1;
        const renderedLogoCount = document.querySelectorAll('.eclipsefdn-members-list img').length;
        const placeholderTextElement = document.querySelector(`.eclipsefdn-members-list a[title="${participatingOrganizations[0].name}"]`);
        expect(renderedLogoCount).toEqual(expectedLogoCount);
        expect(placeholderTextElement.innerHTML).toEqual(participatingOrganizations[0].name);
    }));
});
