"use strict";
/**
 * @jest-environment jsdom
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2023 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Olivier Goulet <olivier.goulet@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */
const eclipsefdn_newsroom_resources_1 = __importDefault(require("../eclipsefdn.newsroom-resources"));
const newsroomAPIModule = __importStar(require("../../api/eclipsefdn.newsroom"));
const mock_data_1 = require("../../api/tests/mocks/newsroom/mock-data");
describe('eclipsefdn-newsroom-resources', () => {
    let getNewsroomResourcesSpy;
    beforeEach(() => {
        getNewsroomResourcesSpy = jest.spyOn(newsroomAPIModule, 'getNewsroomResources');
    });
    it('Template "list": Renders the correct number of resource items when the page size is set to 3', () => __awaiter(void 0, void 0, void 0, function* () {
        // It is expected that there will be 3 items for each resouce type
        getNewsroomResourcesSpy.mockReturnValue([mock_data_1.mockNewsroomResources, null]);
        document.querySelector('body').innerHTML = `
      <div
        class="newsroom-resources"
        data-res-type="case_study, white_paper"
        data-page-size="3"
        data-res-title="Case Studies, White Papers"
        data-res-template="list"
      >
      </div>
    `;
        yield eclipsefdn_newsroom_resources_1.default.render();
        // The `getNewsroomResources` function should have been called twice.
        // Once for each resource type. Both calls should have requested 3 items.
        expect(getNewsroomResourcesSpy).toHaveBeenNthCalledWith(1, expect.objectContaining({ pageSize: 3 }));
        expect(getNewsroomResourcesSpy).toHaveBeenNthCalledWith(2, expect.objectContaining({ pageSize: 3 }));
    }));
    it('Template "cover": Renders the correct number of resource items when page size is set to 3', () => __awaiter(void 0, void 0, void 0, function* () {
        getNewsroomResourcesSpy.mockReturnValue([mock_data_1.mockNewsroomResources, null]);
        document.querySelector('body').innerHTML = `
      <div 
        class="newsroom-resources" 
        data-page-size="3" 
        data-res-title="Case Studies"
        data-res-template="cover"
        data-res-view-more="https://iot.eclipse.org/case-studies/"
      >
      </div>
    `;
        yield eclipsefdn_newsroom_resources_1.default.render();
        expect(getNewsroomResourcesSpy).toHaveBeenCalledWith(expect.objectContaining({ pageSize: 3 }));
    }));
    it('Template "cover": Renders title', () => __awaiter(void 0, void 0, void 0, function* () {
        getNewsroomResourcesSpy.mockReturnValue([mock_data_1.mockNewsroomResources, null]);
        const title = 'Case Studies';
        document.querySelector('body').innerHTML = `
      <div 
        class="newsroom-resources" 
        data-page-size="3" 
        data-res-title="${title}"
        data-res-type="case_study" 
        data-res-wg="eclipse_iot"
        data-res-template="cover"
        data-res-view-more="https://iot.eclipse.org/case-studies/"
      >
      </div>
    `;
        yield eclipsefdn_newsroom_resources_1.default.render();
        const newsroomResourcesTitleElement = document.querySelector('.newsroom-resource-section-title');
        expect(newsroomResourcesTitleElement.textContent).toBe(title);
    }));
});
