"use strict";
/**
* @jest-environment jsdom
*/
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/*!
 * Copyright (c) 2023 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Olivier Goulet <olivier.goulet@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */
const eclipsefdn_projects_1 = __importDefault(require("../eclipsefdn.projects"));
const mock_data_1 = require("../../api/tests/mocks/projects/mock-data");
const projectsAPIModule = __importStar(require("../../api/eclipsefdn.projects"));
const utils_1 = require("../../utils/utils");
jest.mock('list.js');
const list_js_1 = __importDefault(require("list.js"));
describe('eclipsefdn-projects', () => {
    let getProjectsDataSpy;
    beforeEach(() => {
        getProjectsDataSpy = jest.spyOn(projectsAPIModule, 'getProjectsData');
        const originalList = new list_js_1.default();
        list_js_1.default.mockImplementation(() => (Object.assign(Object.assign({}, originalList), { on: jest.fn() })));
    });
    afterAll(() => {
        jest.restoreAllMocks();
    });
    it('Renders static projects from a local JSON file', () => {
        getProjectsDataSpy.mockReturnValue([
            {
                "name": "Eclipse Che",
                "summary": "Eclipse Che is a Kubernetes-native IDE that makes Kubernetes development accessible for development teams, providing one-click developer workspaces and eliminating local environment configuration for your entire team.",
                "logo": "https://www.eclipse.org/che/images/che-logo-64.png",
                "category": "Tools",
                "website_url": "https://www.eclipse.org/che/",
                "version": "7.0.0",
                "state": "Active",
                "isProposal": false
            },
        ]);
        const staticSourceUrl = './static-projects.json';
        document.querySelector('body').innerHTML = `
            <div class="featured-projects" data-is-static-source="true" data-types="projects" data-url="${staticSourceUrl}"></div>
        `;
        eclipsefdn_projects_1.default.render();
        expect(getProjectsDataSpy).toHaveBeenCalledWith(staticSourceUrl, true);
    });
    it('Renders projects from an external source (ex. Projects API)', () => {
        getProjectsDataSpy.mockReturnValue([
            {
                "name": "Eclipse Che",
                "summary": "Eclipse Che is a Kubernetes-native IDE that makes Kubernetes development accessible for development teams, providing one-click developer workspaces and eliminating local environment configuration for your entire team.",
                "logo": "https://www.eclipse.org/che/images/che-logo-64.png",
                "category": "Tools",
                "website_url": "https://www.eclipse.org/che/",
                "version": "7.0.0",
                "state": "Active",
                "isProposal": false
            },
        ]);
        const url = 'https://api.eclipse.org/api/projects?working_group=internet-things-iot';
        document.querySelector('body').innerHTML = `
            <div class="featured-projects" data-is-static-source="false" data-types="projects" data-url="${url}"></div>
        `;
        eclipsefdn_projects_1.default.render();
        expect(getProjectsDataSpy).toHaveBeenCalledWith(url, false);
    });
    it('The page size option limits the number of projects displayed', () => __awaiter(void 0, void 0, void 0, function* () {
        const mockProjects = mock_data_1.mockProjectsCategorizedByIndustryCollaboration['jakarta-ee'];
        getProjectsDataSpy.mockReturnValue(mockProjects);
        const url = 'https://api.eclipse.org/api/projects?working_group=jakarta-ee';
        document.querySelector('body').innerHTML = `
            <div class="featured-projects" data-url="${url}" data-page-size="3"></div>
        `;
        const featuredProjectsElement = document.querySelector('.featured-projects');
        eclipsefdn_projects_1.default.render();
        yield (0, utils_1.waitForRender)(featuredProjectsElement);
        const projectElements = document.querySelectorAll('.featured-projects-item');
        expect(projectElements).toHaveLength(3);
    }));
    it('Sorting method allows for random sorting of projects', () => __awaiter(void 0, void 0, void 0, function* () {
        // Just checking whether or not the Math.random() function is called
        // is enough to ensure that the sorting method is random. It wouldn't
        // be practical to test randomness.
        let randomSpy = jest.spyOn(Math, 'random');
        const mockProjects = mock_data_1.mockProjectsCategorizedByIndustryCollaboration['jakarta-ee'];
        getProjectsDataSpy.mockReturnValue(mockProjects);
        const url = 'https://api.eclipse.org/api/projects?working_group=jakarta-ee';
        document.querySelector('body').innerHTML = `
            <div class="featured-projects" data-url="${url}" data-sorting-method="random"></div>
        `;
        const featuredProjectsElement = document.querySelector('.featured-projects');
        eclipsefdn_projects_1.default.render();
        yield (0, utils_1.waitForRender)(featuredProjectsElement);
        expect(randomSpy).toHaveBeenCalled();
    }));
});
