"use strict";
/**
 * @jest-environment jsdom
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2023 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Olivier Goulet <olivier.goulet@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */
const eclipsefdn_video_list_1 = __importDefault(require("../eclipsefdn.video-list"));
const mediaLinkModule = __importStar(require("../../api/eclipsefdn.media-link"));
const eclipsefdn_video_list_mock_data_1 = require("./mocks/eclipsefdn.video-list-mock-data");
describe('eclipsefdn-video-list', () => {
    let getPlaylistsSpy;
    beforeEach(() => {
        getPlaylistsSpy = jest.spyOn(mediaLinkModule.youtube, 'getPlaylists');
    });
    it("Don't render video list without playlist ids and log error", () => __awaiter(void 0, void 0, void 0, function* () {
        const consoleSpy = jest.spyOn(console, 'error').mockImplementation(() => { });
        document.querySelector('body').innerHTML = `
            <div class="eclipsefdn-video-list"></div>
        `;
        eclipsefdn_video_list_1.default.render();
        // Expect a loading spinner to display
        const loadingElement = document.querySelector('.fa-spinner');
        expect(loadingElement).toBeDefined();
        // Ensure that no video list items are shown
        const videoListElements = document.querySelectorAll('.video-list-item');
        expect(videoListElements.length).toBe(0);
        // Ensure the proper error message is displayed
        expect(consoleSpy).toHaveBeenCalledWith('No playlist id(s) provided');
        consoleSpy.mockRestore();
    }));
    it('Render playlist item when a single playlist id is provided', () => __awaiter(void 0, void 0, void 0, function* () {
        const playlistId = 'PLy7t4z5SYNaTxmWWrnLYshYKaSLhRKNk-';
        getPlaylistsSpy.mockReturnValue([eclipsefdn_video_list_mock_data_1.playlists.filter(p => p.id === playlistId), null]);
        document.querySelector('body').innerHTML = `
            <div 
                class="eclipsefdn-video-list" 
                data-playlist-ids="${playlistId}"
            >
            </div>
        `;
        yield eclipsefdn_video_list_1.default.render();
        // Ensures that the correct playlist id is given to the api function
        expect(getPlaylistsSpy).toHaveBeenCalledWith([playlistId]);
        // Ensures that only one video list item is present
        const videoListElements = document.querySelectorAll('.video-list-item');
        expect(videoListElements.length).toBe(1);
        getPlaylistsSpy.mockRestore();
    }));
    it('Renders multiple playlists when multiple playlist ids are provided', () => __awaiter(void 0, void 0, void 0, function* () {
        const playlistIds = [eclipsefdn_video_list_mock_data_1.playlists[0].id, eclipsefdn_video_list_mock_data_1.playlists[1].id];
        const matchingPlaylistMocks = eclipsefdn_video_list_mock_data_1.playlists.filter(p => playlistIds.includes(p.id));
        getPlaylistsSpy.mockReturnValue([matchingPlaylistMocks, null]);
        document.querySelector('body').innerHTML = `
            <div
                class="eclipsefdn-video-list"
                data-playlist-ids="${playlistIds.join(',')}"
            >
            </div>
        `;
        yield eclipsefdn_video_list_1.default.render();
        // Ensures that the correct playlist ids were given to the api function
        expect(getPlaylistsSpy).toHaveBeenCalledWith(playlistIds);
        // Ensures that the correct number of video list items were rendered
        const videoListElements = document.querySelectorAll('.video-list-item');
        expect(videoListElements.length).toBe(playlistIds.length);
        // Ensure that the correct video list items were listed by comparing titles
        const videoListTitles = new Set(Array.from(document.querySelectorAll('.video-details-title')).map(titleElement => titleElement.textContent));
        expect(videoListTitles).toEqual(new Set(matchingPlaylistMocks.map(p => p.title)));
        getPlaylistsSpy.mockRestore();
    }));
    it('Modify the max length of the descriptions of video list items', () => __awaiter(void 0, void 0, void 0, function* () {
        // Overwrite the mock data description in-case the mock data changes. 
        // We don't want this test to break if playlistsMock[0] were to change.
        const playlistMock = Object.assign(Object.assign({}, eclipsefdn_video_list_mock_data_1.playlists[0]), { description: 'This is a short description for a video list item' });
        getPlaylistsSpy.mockReturnValue([[playlistMock], null]);
        const descriptionMaxLength = 30;
        document.querySelector('body').innerHTML = `
            <div
                class="eclipsefdn-video-list"
                data-playlist-ids="${playlistMock.id}"
                data-description-max-length="${descriptionMaxLength}"
            >
            </div>
        `;
        yield eclipsefdn_video_list_1.default.render();
        const descriptionElement = document.querySelector('.video-details-description');
        // Ensures that the description is the correct length including an ellipsis
        expect(descriptionElement.textContent).toEqual(playlistMock.description.substring(0, descriptionMaxLength - 3).concat('...'));
    }));
});
