"use strict";
/**
 * @jest-environment jsdom
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2023 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Olivier Goulet <olivier.goulet@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */
const render_template_1 = __importDefault(require("../templates/render-template"));
const templates = {
    default: () => `<div>Default Template</div>`,
    alternative: () => `<div>Alternative Template</div>`,
    'data-template': text => `<div>${text}</div>`,
};
describe('renderTemplate', () => {
    afterEach(() => {
        document.querySelector('body').innerHTML = '';
    });
    it('Renders the specified template', () => __awaiter(void 0, void 0, void 0, function* () {
        const wrapperElement = document.createElement('div');
        // Expect the 'default' template to render inside the wrapper element
        let templateName = 'default';
        yield (0, render_template_1.default)(wrapperElement, templates, templateName);
        expect(wrapperElement.innerHTML).toEqual(templates[templateName]());
        // Expect the 'alternative' template to render inside the wrapper element
        templateName = 'alternative';
        yield (0, render_template_1.default)(wrapperElement, templates, templateName);
        expect(wrapperElement.innerHTML).toEqual(templates[templateName]());
    }));
    it('Renders custom templates', () => __awaiter(void 0, void 0, void 0, function* () {
        const customTemplate = `<div>Custom Template</div>`;
        document.querySelector('body').innerHTML = `
            <script id="custom-template" type="x-tmpl-mustache">
                ${customTemplate}
            </script>
        `;
        const wrapperElement = document.createElement('div');
        // Expect the template defined in the #custom-template script to render inside the wrapper
        // element
        yield (0, render_template_1.default)(wrapperElement, templates, 'custom-template');
        expect(wrapperElement.innerHTML.trim()).toEqual(customTemplate);
    }));
    it('Renders data given to the template', () => __awaiter(void 0, void 0, void 0, function* () {
        const textData = 'This is some text data';
        const wrapperElement = document.createElement('div');
        yield (0, render_template_1.default)(wrapperElement, templates, 'data-template', textData);
        expect(wrapperElement.innerHTML).toContain(textData);
    }));
    it('Shows error message when template could not be found', () => __awaiter(void 0, void 0, void 0, function* () {
        const consoleSpy = jest.spyOn(console, 'error').mockImplementation(() => { });
        const wrapperElement = document.createElement('div');
        yield (0, render_template_1.default)(wrapperElement, templates, 'undefined-template');
        expect(wrapperElement.innerHTML).toBe('');
        expect(consoleSpy).toHaveBeenCalledWith(expect.stringContaining('has not been found'));
        consoleSpy.mockRestore();
    }));
});
