/*
 * Copyright (c) 2023 Eclipse Foundation, Inc.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * Contributors:
 *   Olivier Goulet <olivier.goulet@eclipse-foundation.org>
 *
 * SPDX-License-Identifier: EPL-2.0
 */

import { getProjectProposals } from '../eclipsefdn.projects';
import {
  mockProposals,
  mockProposalsCategorizedByIndustryCollaboration,
} from './mocks/projects/mock-data';

describe('Projects API', () => {
  it('Fetches all proposals', async () => {
    const [result, error] = await getProjectProposals();

    expect(result).not.toBeNull();
    expect(error).toBeNull();
    expect(result).toHaveLength(mockProposals.length);
    expect(result[0]).toHaveProperty('project_id');
  });

  it('Fetches proposals for a specific industry collaboration', async () => {
    const [result, error] = await getProjectProposals('jakarta-ee');

    expect(result).not.toBeNull();
    expect(error).toBeNull();
    expect(result).toHaveLength(
      mockProposalsCategorizedByIndustryCollaboration['jakarta-ee'].length
    );
    expect(result[0]).toHaveProperty('project_id');
  });

  it('Resolves empty array when no proposals found', async () => {
    const [result] = await getProjectProposals('eclipse-software-defined-vehicle');

    expect(result).toEqual([]);
  });
});
